/**
 * EasyBeans
 * Copyright (C) 2006-2007 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: DefaultArchiveFactory.java 1494 2007-06-28 16:57:29Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.deploy.impl.archive;

import java.io.File;
import java.io.IOException;
import java.util.jar.JarFile;

import org.ow2.util.ee.deploy.api.archive.ArchiveFactory;
import org.ow2.util.ee.deploy.api.archive.IArchive;
import org.ow2.util.log.Log;
import org.ow2.util.log.LogFactory;

/**
 * Default factory that manages the file (jar file or directories).
 * @author Florent Benoit
 */
public class DefaultArchiveFactory implements ArchiveFactory<File> {

    /**
     * Logger.
     */
    private Log logger = LogFactory.getLog(DefaultArchiveFactory.class);

    /**
     * Creates an EZBArchive object for the given object.
     * @param file the file that this factory can manage.
     * @return a new EZBArchive instance or null if it's not an archive
     */
    public IArchive create(final File file) {
        if (file.isDirectory()) {
            return new DirectoryArchiveImpl(file);
        }

        // check that this is a valid JAR file, else return null
        JarFile jarFile = null;
        try {
            jarFile = new JarFile(file);
        } catch (IOException e) {
            // not a valid jar file
            logger.debug("File ''{0}'' is not a valid Jar File", file);
            return null;
        } finally {
            if (jarFile != null) {
                try {
                    jarFile.close();
                } catch (IOException e) {
                    logger.debug("Cannot close the jar file ''{0}''", jarFile);
                }
            }
        }

        return new JarArchiveImpl(file);
    }

}
